/*==============================================================================
 The Fraclet Programming Model - Fractal Component Model (fractal@objectweb.org)
 Copyright (C) 2002-2006 INRIA Futurs / LIFL
 Copyright (C) 2006-2007 Universitetet i Oslo

 This library is free software; you can redistribute it and/or modify it under 
 the terms of the GNU Lesser General Public License as published by the Free 
 Software Foundation; either version 2.1 of the License, or any later version.

 This library is distributed in the hope that it will be useful, but WITHOUT ANY 
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public License along 
 with this library; if not, write to the Free Software Foundation, Inc., 
 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

 Initial developer(s): Romain Rouvoy
 Contributor(s): 
 =============================================================================*/
package org.objectweb.fractal.helloworld;

import static java.util.logging.Logger.getLogger;
import static org.objectweb.fractal.fraclet.types.Step.CREATE;

import java.util.logging.Logger;

import org.objectweb.fractal.api.control.NameController;
import org.objectweb.fractal.fraclet.annotations.Attribute;
import org.objectweb.fractal.fraclet.annotations.Component;
import org.objectweb.fractal.fraclet.annotations.Controller;
import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Lifecycle;
import org.objectweb.fractal.fraclet.annotations.Requires;

/**
 * Implementation of a Helloworld client component.
 * @author Romain Rouvoy (Initial Developer)
 * @version $Revision$
 */
@Component(name = "helloworld.Client", provides = @Interface(name = "r", signature = Runnable.class))
public class Client implements Runnable {
    private final Logger log = getLogger("client");
    @Attribute(value="Hello world") 
    private String message;
    @Requires(name="s") 
    private Service service;
    @Controller("name-controller") 
    protected NameController nc;
    
    @Lifecycle(CREATE) 
    protected void whenCreated() { 
        log.info("helloworld.Client - created."); 
    }
    
    /* (non-Javadoc)
     * @see java.lang.Runnable#run()
     */
    public void run() { 
        this.service.print(this.nc.getFcName() + " says " + this.message); 
    }
}