/*==============================================================================
 The Fraclet Programming Model - Fractal Component Model (fractal@objectweb.org)
 Copyright (C) 2002-2006 INRIA Futurs / LIFL
 Copyright (C) 2006-2007 Universitetet i Oslo

 This library is free software; you can redistribute it and/or modify it under 
 the terms of the GNU Lesser General Public License as published by the Free 
 Software Foundation; either version 2.1 of the License, or any later version.

 This library is distributed in the hope that it will be useful, but WITHOUT ANY 
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public License along 
 with this library; if not, write to the Free Software Foundation, Inc., 
 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

 Initial developer(s): Romain Rouvoy
 Contributor(s): 
 =============================================================================*/
package org.objectweb.fractal.adl.spoonlet.composite;

import static org.objectweb.fractal.adl.spoonlet.composite.DefinitionGenerator.composite;

import org.objectweb.fractal.adl.spoonlet.component.ComponentProcessor;
import org.objectweb.fractal.document.Factory;
import org.objectweb.fractal.fraclet.annotations.Component;
import org.objectweb.fractal.fraclet.annotations.Requires;

import spoon.processing.Property;
import spoon.reflect.declaration.CtClass;
import spoon.reflect.declaration.CtSimpleType;

/**
 * Processor interpreting the annotation <code>Component</code> to generate
 * the associated composite <code>definition</code> element in Fractal ADL
 * definitions.
 * 
 * @author Romain Rouvoy (Initial Developer)
 * @version $Revision$
 */
public class CompositeProcessor extends ComponentProcessor {
    @Property("Suffix added to the composite definition (default is Composite)")
    private String extension = "Composite";

    /* (non-Javadoc)
     * @see org.objectweb.fractal.adl.spoonlet.component.ComponentProcessor#process(org.objectweb.fractal.fraclet.annotations.Component, spoon.reflect.declaration.CtClass)
     */
    @Override
    public void process(Component ann, CtClass<?> cls) {
        if (cls.getAnnotatedChildren(Requires.class).size()==0)
            return;
        super.process(ann,cls);
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.fractal.adl.spoonlet.component.ComponentProcessor#getComponentName(spoon.reflect.declaration.CtSimpleType, org.objectweb.fractal.fraclet.annotations.Component)
     */
    @Override
    protected String getComponentName(CtSimpleType<?> comp, Component ann) {
        return super.getComponentName(comp, ann) + this.extension;
    }

    /* (non-Javadoc)
     * @see org.objectweb.fractal.adl.spoonlet.definition.AbstractDefinitionProcessor#factory()
     */
    @Override
    protected Factory factory() {
        return composite();
    }
}
